========================
django-codenerix-vending
========================

Codenerix Vending is a module that enables `CODENERIX <https://www.codenerix.com/>`_ to work as a Point Of Sales system focused for business faced to final client (services, supermarkets & shops, examples: retaurants, petrol stations, clothes shops, grocery store, hardware store and others).

.. image:: https://github.com/codenerix/django-codenerix/raw/master/codenerix/static/codenerix/img/codenerix.png
    :target: https://www.codenerix.com
    :alt: Try our demo with Codenerix Cloud

****
Demo
****

You can have a look to our demos online:

* `CODENERIX Simple Agenda DEMO <http://demo.codenerix.com>`_.
* `CODENERIX Full ERP DEMO <https://erp.codenerix.com>`_.

You can find some working examples in GITHUB at `django-codenerix-examples <https://github.com/codenerix/django-codenerix-examples>`_ project.

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-vending
    For python 3: sudo pip3 install django-codenerix-vending

2. Add "codenerix_vending" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_vending',
    ]

3. Add in settings the params::

    # add legal terms image to be printed on tickets from thermal printer
    INFO_TERMS_VENDING = "img/terms_ticket_vending.png"

4. Since Codenerix Vending is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us?

You can get in touch with us `here <https://codenerix.com/contact/>`_.
